@@ -40,8 +40,8 @@ except ImportError:  # should only happen at compile time
 _PATH_FINDER = hu.PathFinder()
 _HADOOP_INFO = _PATH_FINDER.find()  # fill the cache ASAP
 
-__author__ = "Simone Leo, Gianluigi Zanetti, Luca Pireddu, Francesco Cabras"
-__author_email__ = "<simone.leo@crs4.it>, <gianluigi.zanetti@crs4.it>, <luca.pireddu@crs4.it>, <francesco.cabras@crs4.it>"
+__author__ = "Simone Leo, Gianluigi Zanetti, Luca Pireddu, Francesco Cabras, Mauro Del Rio"
+__author_email__ = "<simone.leo@crs4.it>, <gianluigi.zanetti@crs4.it>, <luca.pireddu@crs4.it>, <francesco.cabras@crs4.it>, <mauro@crs4.it>"
 __url__ = "http://pydoop.sourceforge.net"
 
 
@@ -77,6 +77,10 @@ def hadoop_params(hadoop_conf=None, hadoop_home=None):
   return _PATH_FINDER.hadoop_params(hadoop_conf, hadoop_home)
 
 
+def hadoop_native(hadoop_home=None):
+  return _PATH_FINDER.hadoop_native(hadoop_home)
+
+
 def hadoop_classpath(hadoop_home=None):
   return _PATH_FINDER.hadoop_classpath(hadoop_home)
 
